pub struct RunHistory {
pub default_runtime_settings: RuntimeSettings,
pub cli_settings: CLISettings,
pub command_blocks: Vec<CommandsBlock>,
pub commands: Vec<CommandHistory>,
}Fields
default_runtime_settings: RuntimeSettingsDefault runtime settings restored before replaying the recorded commands.
cli_settings: CLISettingsState and global CLI settings captured with this run history.
command_blocks: Vec<CommandsBlock>Named reusable command sequences declared by run cards.
commands: Vec<CommandHistory>Ordered top-level commands persisted for replay.
Implementations
Sourceimpl RunHistory
impl RunHistory
pub fn freeze_boot_settings_from(&mut self, boot_run_history: &RunHistory)
pub fn frozen_boot_settings_match(&self, boot_run_history: &RunHistory) -> bool
Sourcepub fn push_with_raw(&mut self, command: Commands, raw_string: Option<String>)
pub fn push_with_raw(&mut self, command: Commands, raw_string: Option<String>)
Add a command with optional raw string to the run history
If raw_string is provided, it will be stored alongside the command for potential later serialization as a string.
pub fn schema() -> Schema
pub fn validate(&self) -> Result<()>
pub fn command_block(&self, name: &str) -> Option<&CommandsBlock>
pub fn select_command_blocks( &self, selected_block_names: &[String], ) -> Result<Vec<CommandsBlock>>
pub fn conflicting_command_block_names( &self, command_blocks: &[CommandsBlock], ) -> Vec<String>
pub fn merge_command_blocks_with_overwrite( &mut self, command_blocks: &[CommandsBlock], overwrite_conflicts: bool, ) -> Result<()>
pub fn merge_command_blocks( &mut self, command_blocks: &[CommandsBlock], ) -> Result<()>
pub fn apply_session_settings( &self, global_settings: &mut CLISettings, default_runtime_settings: &mut RuntimeSettings, ) -> Result<()>
pub fn run( &mut self, state: &mut State, global_settings: &mut CLISettings, default_runtime_settings: &mut RuntimeSettings, ) -> Result<ControlFlow<SaveState>>
pub fn load(path: impl AsRef<Path>) -> Result<Self>
pub fn save_toml( &self, root_folder: &Path, override_state_file: bool, _strict: bool, ) -> Result<()>
pub fn save_yaml( &self, root_folder: &Path, override_state_file: bool, _strict: bool, ) -> Result<()>