pub struct QuadFloat(/* private fields */);Trait Implementations
Sourceimpl AddAssign for QuadFloat
impl AddAssign for QuadFloat
Sourcefn add_assign(&mut self, rhs: Self)
fn add_assign(&mut self, rhs: Self)
Performs the
+= operation. Read moreSourceimpl AddAssign<&QuadFloat> for QuadFloat
impl AddAssign<&QuadFloat> for QuadFloat
Sourcefn add_assign(&mut self, rhs: &Self)
fn add_assign(&mut self, rhs: &Self)
Performs the
+= operation. Read moreSourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for QuadFloat
impl<'__de, __Context> BorrowDecode<'__de, __Context> for QuadFloat
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
impl Copy for QuadFloat
Sourceimpl<'de> Deserialize<'de> for QuadFloat
impl<'de> Deserialize<'de> for QuadFloat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl DivAssign for QuadFloat
impl DivAssign for QuadFloat
Sourcefn div_assign(&mut self, rhs: Self)
fn div_assign(&mut self, rhs: Self)
Performs the
/= operation. Read moreSourceimpl DivAssign<&QuadFloat> for QuadFloat
impl DivAssign<&QuadFloat> for QuadFloat
Sourcefn div_assign(&mut self, rhs: &Self)
fn div_assign(&mut self, rhs: &Self)
Performs the
/= operation. Read moreimpl Eq for QuadFloat
Sourceimpl EvaluationDomain for QuadFloat
impl EvaluationDomain for QuadFloat
Sourceconst FIXED_PRECISION: Option<u32> = <DoubleFloat as EvaluationDomain>::FIXED_PRECISION
const FIXED_PRECISION: Option<u32> = <DoubleFloat as EvaluationDomain>::FIXED_PRECISION
The single supported binary precision for fixed-precision domains. Read more
Sourcefn try_from_complex_float(f: Complex<Float>) -> Result<Self, String>
fn try_from_complex_float(f: Complex<Float>) -> Result<Self, String>
Try to convert a
Complex<Float> to the type.fn resolve_function(
tags: &[AtomView<'_>],
info: &EvaluationInfo,
) -> Option<Box<dyn ExternalFunction<Self, Output = Self>>>
fn resolve_function( tags: &[AtomView<'_>], info: &EvaluationInfo, ) -> Option<Box<dyn ExternalFunction<Self, Output = Self>>>
Resolve a function implementation for the given tags, if available for the type.
If no implementation exists for the type, a conversion from a ‘larger’ type may
be used instead.
Sourceimpl ExportNumber for QuadFloat
impl ExportNumber for QuadFloat
Sourcefn to_complex_double(&self) -> Complex<f64>
fn to_complex_double(&self) -> Complex<f64>
Convert the number to a complex double.
fn export_wrapped(&self) -> String
fn export_wrapped(&self) -> String
Export the number wrapped in a C++ type
T.fn export_wrapped_with(&self, wrapper: &str) -> String
fn export_wrapped_with(&self, wrapper: &str) -> String
Export the number wrapped in a C++ type
wrapper.Sourceimpl FixedPrecision for QuadFloat
impl FixedPrecision for QuadFloat
Sourceconst BINARY_PRECISION: usize = <DoubleFloat as FixedPrecision>::BINARY_PRECISION
const BINARY_PRECISION: usize = <DoubleFloat as FixedPrecision>::BINARY_PRECISION
The number of binary digits in the mantissa.
const DECIMAL_PRECISION: usize = _
const DECIMAL_PRECISION: usize = _
The (rounded) number of decimal digits in the mantissa.
Sourceimpl FloatLike for QuadFloat
impl FloatLike for QuadFloat
Sourcefn is_fully_zero(&self) -> bool
fn is_fully_zero(&self) -> bool
Return true if the number is exactly equal to zero (in all components).
fn from_i64(&self, a: i64) -> Self
fn from_usize(&self, a: usize) -> Self
Sourcefn get_precision(&self) -> u32
fn get_precision(&self) -> u32
Get the number of precise binary digits.
fn zero(&self) -> Self
fn one(&self) -> Self
Sourcefn new_zero() -> Self
fn new_zero() -> Self
Create a zero that should only be used as a temporary value,
as for some types it may have wrong precision information.
fn inv(&self) -> Self
fn pow(&self, e: u64) -> Self
Sourcefn sample_unit<R: Rng + ?Sized>(&self, rng: &mut R) -> Self
fn sample_unit<R: Rng + ?Sized>(&self, rng: &mut R) -> Self
Sample a point on the interval [0, 1].
fn neg(&self) -> Self
fn get_epsilon(&self) -> f64
Sourcefn fixed_precision(&self) -> bool
fn fixed_precision(&self) -> bool
Return true iff the precision is fixed, or false
if the precision is changed dynamically.
Sourceimpl MulAssign for QuadFloat
impl MulAssign for QuadFloat
Sourcefn mul_assign(&mut self, rhs: Self)
fn mul_assign(&mut self, rhs: Self)
Performs the
*= operation. Read moreSourceimpl MulAssign<&QuadFloat> for QuadFloat
impl MulAssign<&QuadFloat> for QuadFloat
Sourcefn mul_assign(&mut self, rhs: &Self)
fn mul_assign(&mut self, rhs: &Self)
Performs the
*= operation. Read moreSourceimpl PartialOrd for QuadFloat
impl PartialOrd for QuadFloat
impl R for QuadFloat
Sourceimpl Real for QuadFloat
impl Real for QuadFloat
fn conj(&self) -> Self
fn atan2(&self, x: &Self) -> Self
fn powf(&self, e: &Self) -> Self
fn log(&self) -> Self
fn norm(&self) -> Self
fn sqrt(&self) -> Self
fn exp(&self) -> Self
fn sin(&self) -> Self
fn cos(&self) -> Self
fn tan(&self) -> Self
fn asin(&self) -> Self
fn acos(&self) -> Self
fn sinh(&self) -> Self
fn cosh(&self) -> Self
fn tanh(&self) -> Self
fn asinh(&self) -> Self
fn acosh(&self) -> Self
fn atanh(&self) -> Self
impl StructuralPartialEq for QuadFloat
Sourceimpl SubAssign for QuadFloat
impl SubAssign for QuadFloat
Sourcefn sub_assign(&mut self, rhs: Self)
fn sub_assign(&mut self, rhs: Self)
Performs the
-= operation. Read moreSourceimpl SubAssign<&QuadFloat> for QuadFloat
impl SubAssign<&QuadFloat> for QuadFloat
Sourcefn sub_assign(&mut self, rhs: &Self)
fn sub_assign(&mut self, rhs: &Self)
Performs the
-= operation. Read moreSourceimpl UpdateAndGetParams<QuadFloat> for ParamBuilder<f64>
impl UpdateAndGetParams<QuadFloat> for ParamBuilder<f64>
fn update_emr_and_get_params<'a>( &'a mut self, _cache: (bool, bool), sample: &MomentumSample<f128>, graph: &Graph, helicities: &[Helicity], additional_params: &[F<f128>], left_threshold_params: Option<&ThresholdParams<f128>>, right_threshold_params: Option<&ThresholdParams<f128>>, lu_params: Option<&LUParams<f128>>, ) -> InputParams<'a, f128>