pub struct Select {Show 27 fields
pub process: Option<ProcessRef>,
pub integrand_name: Option<String>,
pub amplitude_graphs: bool,
pub with_graph_names: Vec<String>,
pub with_only_graph_names: Vec<String>,
pub without_graph_names: Vec<String>,
pub with_raised_propagator_signatures: Vec<String>,
pub without_raised_propagator_signatures: Vec<String>,
pub with_massive_raised_propagator_signatures: Vec<String>,
pub without_massive_raised_propagator_signatures: Vec<String>,
pub with_massless_raised_propagator_signatures: Vec<String>,
pub without_massless_raised_propagator_signatures: Vec<String>,
pub with_raised_cuts_signatures: Vec<String>,
pub without_raised_cuts_signatures: Vec<String>,
pub with_massive_raised_cuts_signatures: Vec<String>,
pub without_massive_raised_cuts_signatures: Vec<String>,
pub with_massless_raised_cuts_signatures: Vec<String>,
pub without_massless_raised_cuts_signatures: Vec<String>,
pub with_cycle_signatures: Vec<String>,
pub without_cycle_signatures: Vec<String>,
pub with_vertices: Vec<String>,
pub without_vertices: Vec<String>,
pub with_particles: Vec<String>,
pub without_particles: Vec<String>,
pub output_process: Option<String>,
pub output_integrand: Option<String>,
pub clear_existing_processes: bool,
}Fields
process: Option<ProcessRef>Process reference: #<id>, name:<name>, or <id>/<name>
integrand_name: Option<String>Integrand name inside the selected process
amplitude_graphs: boolApply structural filters to left/right amplitude graphs of cross-section cuts
with_graph_names: Vec<String>Retain graph groups with these master graph names
with_only_graph_names: Vec<String>Retain exactly these graph groups and ignore every other selection filter
without_graph_names: Vec<String>Remove graph groups with these master graph names
with_raised_propagator_signatures: Vec<String>Retain graph groups with one of these raised-propagator signatures
without_raised_propagator_signatures: Vec<String>Remove graph groups with one of these raised-propagator signatures
with_massive_raised_propagator_signatures: Vec<String>Retain graph groups with one of these massive raised-propagator signatures
without_massive_raised_propagator_signatures: Vec<String>Remove graph groups with one of these massive raised-propagator signatures
with_massless_raised_propagator_signatures: Vec<String>Retain graph groups with one of these massless raised-propagator signatures
without_massless_raised_propagator_signatures: Vec<String>Remove graph groups with one of these massless raised-propagator signatures
with_raised_cuts_signatures: Vec<String>Retain graph groups where a process-valid cut touches one of these raised-propagator group signatures
without_raised_cuts_signatures: Vec<String>Remove graph groups where a process-valid cut touches one of these raised-propagator group signatures
with_massive_raised_cuts_signatures: Vec<String>Retain graph groups where a process-valid cut touches one of these massive raised-propagator group signatures
without_massive_raised_cuts_signatures: Vec<String>Remove graph groups where a process-valid cut touches one of these massive raised-propagator group signatures
with_massless_raised_cuts_signatures: Vec<String>Retain graph groups where a process-valid cut touches one of these massless raised-propagator group signatures
without_massless_raised_cuts_signatures: Vec<String>Remove graph groups where a process-valid cut touches one of these massless raised-propagator group signatures
with_cycle_signatures: Vec<String>Retain graph groups matching one of these cycle signatures
without_cycle_signatures: Vec<String>Remove graph groups matching one of these cycle signatures
with_vertices: Vec<String>Retain graph groups containing at least one of these vertex-rule multisets
without_vertices: Vec<String>Remove graph groups containing at least one of these vertex-rule multisets
with_particles: Vec<String>Retain graph groups containing all particles from at least one of these particle sets
without_particles: Vec<String>Remove graph groups containing all particles from at least one of these particle sets
output_process: Option<String>Copy the selected graph groups to this output process instead of modifying in place
output_integrand: Option<String>Copy the selected graph groups to this output integrand instead of modifying in place
clear_existing_processes: boolAllow copy-mode selection to replace an existing output process or integrand
Implementations