pub struct Graph {
pub overall_factor: Atom,
pub name: String,
pub group_id: Option<GroupId>,
pub is_group_master: bool,
pub tree_edges: SuBitGraph,
pub underlying: HedgeGraph<Edge, Vertex, HedgeData>,
pub loop_momentum_basis: LoopMomentumBasis,
pub param_builder: ParamBuilder,
pub global_prefactor: GlobalPrefactor,
pub surface_cache: SurfaceCache,
pub initial_state_cut: OrientedCut,
pub polarizations: Vec<(PolDef, Atom)>,
}Fields
overall_factor: Atomname: Stringgroup_id: Option<GroupId>is_group_master: booltree_edges: SuBitGraphunderlying: HedgeGraph<Edge, Vertex, HedgeData>loop_momentum_basis: LoopMomentumBasisparam_builder: ParamBuilderglobal_prefactor: GlobalPrefactorsurface_cache: SurfaceCacheinitial_state_cut: OrientedCutThe cross section initial state cut Only relevant for cross sections, but stored here for the parsing
polarizations: Vec<(PolDef, Atom)>Implementations
Sourceimpl Graph
impl Graph
pub fn to_dot_graph_with_settings( &self, settings: &DotExportSettings, ) -> DotGraph
pub fn to_split_dotgraph(&self) -> DotGraph
Sourceimpl Graph
impl Graph
pub fn dot_serialize(&self, settings: &DotExportSettings) -> String
pub fn dot_serialize_fmt( &self, writer: &mut impl Write, settings: &DotExportSettings, ) -> Result<(), Error>
pub fn from_dot(graph: DotGraph, model: &Model) -> Result<Self>
pub fn from_file<P>(p: P, model: &Model) -> Result<Vec<Self>>
pub fn from_path<P>(p: P, model: &Model) -> Result<Vec<Self>>
pub fn from_string<Str: AsRef<str>>(s: Str, model: &Model) -> Result<Vec<Self>>
Sourceimpl Graph
impl Graph
pub fn debug_dot(&self) -> String
pub fn debug_dot_with_settings(&self, settings: &DotExportSettings) -> String
pub fn pretty_dot(&self) -> String
pub fn get_edges_in_initial_state_cut(&self) -> Vec<EdgeIndex>
Sourceimpl Graph
impl Graph
pub fn generate_polarizations(&self) -> Atom
pub fn generate_polarization_params(&self) -> Vec<Atom>
Methods from Deref<Target = HedgeGraph<Edge, Vertex, HedgeData>>
pub fn check(&self) -> Result<(), HedgeGraphError>
pub fn concretize<'a, S>(
&'a self,
subgraph: &'a S,
) -> HedgeGraph<&'a E, &'a V, &'a H, <N as NodeStorageOps>::OpStorage<&'a V>>where
S: SubSetLike,
pub fn concretize<'a, S>(
&'a self,
subgraph: &'a S,
) -> HedgeGraph<&'a E, &'a V, &'a H, <N as NodeStorageOps>::OpStorage<&'a V>>where
S: SubSetLike,
Creates a new HedgeGraph instance representing a “concretized” view of a given subgraph.
This method effectively extracts the specified subgraph into a new, independent graph.
The new graph contains copies of the nodes and edges (and their data via references)
that are part of the subgraph.
Node and edge data in the new graph are references (&'a V, &'a E) to the data
in the original graph.
Parameters
subgraph: A reference to a subgraphSwithin the current graph.
Returns
A new HedgeGraph containing only the elements of the subgraph.
The node storage type of the new graph is N::OpStorage<&'a V>.
pub fn inv(&self, hedge: Hedge) -> Hedge
pub fn inv(&self, hedge: Hedge) -> Hedge
Gives the involved hedge.
Returns the opposite (or “twin”) half-edge of the given hedge.
- If
hedgeis part of a paired edge, this returns its sibling half-edge. - If
hedgeis an identity (unpaired) half-edge, it returns itself.
Parameters
hedge: The half-edge for which to find the opposite.
Returns
The opposite Hedge.
pub fn is_connected<S>(&self, subgraph: &S) -> boolwhere
S: SubGraphLike,
pub fn is_connected<S>(&self, subgraph: &S) -> boolwhere
S: SubGraphLike,
Checks if the specified subgraph is connected.
A subgraph is connected if there is a path between any two half-edges (or nodes they are incident to) within that subgraph, using only edges also within the subgraph.
Parameters
subgraph: The subgraphSto check for connectivity.
Returns
true if the subgraph is connected, false otherwise.
Returns true for an empty subgraph.
Panics
Panics if the traversal (used internally) fails, which can happen if the
starting node for traversal is not part of the subgraph.
pub fn cut_branches(&self, subgraph: &mut HedgeNode)
pub fn cut_branches(&self, subgraph: &mut HedgeNode)
Modifies a [HedgeNode] subgraph by removing “branches” or “tendrils”.
A branch is typically a path of edges within the subgraph that ultimately
connects to the rest of the subgraph at only one point (one node with degree > 1
within the branch, relative to other branch edges). This operation iteratively
removes edges that are part of such terminal paths until no more such branches exist.
It first removes purely external edges from the subgraph’s internal part,
then iteratively prunes edges that form degree-1 connections within the subgraph’s context.
Finally, it fixes the hairs of the HedgeNode to be consistent.
Parameters
subgraph: A mutable reference to theHedgeNodeto be pruned.
pub fn internal_crown<S>(&self, subgraph: &S) -> <S as SubSetLike>::Basewhere
S: SubSetLike,
<S as SubSetLike>::Base: ModifySubSet<HedgePair>,
pub fn internal_crown<S>(&self, subgraph: &S) -> <S as SubSetLike>::Basewhere
S: SubSetLike,
<S as SubSetLike>::Base: ModifySubSet<HedgePair>,
Calculates the “internal crown” of a given subgraph.
The internal crown consists of all half-edges within the subgraph that are
either unpaired (dangling/external) or part of a “split” edge (i.e., their
opposite half-edge is not in the subgraph). These are effectively the
boundary half-edges of the subgraph from its own perspective.
Parameters
subgraph: The subgraphSfor which to find the internal crown.
Returns
A new subgraph of type S::Base containing the internal crown half-edges.
S::Base must implement ModifySubgraph<HedgePair>.
pub fn full_crown<S>(&self, subgraph: &S) -> <S as SubSetLike>::Basewhere
S: SubSetLike,
<S as SubSetLike>::Base: ModifySubSet<Hedge>,
pub fn full_crown<S>(&self, subgraph: &S) -> <S as SubSetLike>::Basewhere
S: SubSetLike,
<S as SubSetLike>::Base: ModifySubSet<Hedge>,
Calculates the “full crown” of a given subgraph.
The full crown consists of all half-edges that are incident to any node
touched by the subgraph, provided that these half-edges are either
unpaired (identity) or their opposite half-edge is not included in the subgraph.
This is different from internal_crown as it considers all incident edges to
nodes in the subgraph’s footprint, not just edges within the subgraph itself.
It might include edges not present in the initial subgraph.
Parameters
subgraph: The subgraphSfor which to find the full crown.
Returns
A new subgraph of type S::Base containing the full crown half-edges.
S::Base must implement ModifySubgraph<Hedge>.
pub fn add_crown<S>(&self, subgraph: &mut S)where
S: ModifySubSet<Hedge> + SubSetLike,
pub fn add_crown<S>(&self, subgraph: &mut S)where
S: ModifySubSet<Hedge> + SubSetLike,
Add all half-edges that are incident to any node
touched by the subgraph, provided that these half-edges are either
unpaired (identity) or their opposite half-edge is not included in the subgraph.
pub fn external_filter<S>(&self) -> Swhere
S: ModifySubSet<Hedge> + SubSetLike,
pub fn external_filter<S>(&self) -> Swhere
S: ModifySubSet<Hedge> + SubSetLike,
Creates a SuBitGraph representing a subgraph containing all external (identity/dangling)
half-edges in the entire graph.
Returns
A SuBitGraph where bits corresponding to external half-edges are set to true.
pub fn full_filter(&self) -> SubSet<Hedge>
pub fn full_filter(&self) -> SubSet<Hedge>
Creates a SuBitGraph representing a subgraph containing all half-edges in the graph.
Returns
A SuBitGraph of length self.n_hedges() with all bits set to true.
pub fn full(&self) -> FullOrEmpty
pub fn full(&self) -> FullOrEmpty
Returns a [FullOrEmpty] subgraph representing the entire graph (all hedges included).
pub fn empty(&self) -> FullOrEmpty
pub fn empty(&self) -> FullOrEmpty
Returns a [FullOrEmpty] subgraph representing an empty graph (no hedges included).
pub fn clean_subgraph(&self, filter: SubSet<Hedge>) -> InternalSubGraph
pub fn clean_subgraph(&self, filter: SubSet<Hedge>) -> InternalSubGraph
Creates an [InternalSubGraph] from a SuBitGraph filter, ensuring it has no “hairs”.
This uses a “pessimistic” approach: an edge is included only if both its
half-edges are set in the input filter. Dangling edges are removed.
Parameters
filter: ASuBitGraphrepresenting the desired set of half-edges.
Returns
A new InternalSubGraph.
pub fn full_node(&self) -> HedgeNode
pub fn full_node(&self) -> HedgeNode
Returns a [HedgeNode] that represents the entire graph.
The internal_graph of this HedgeNode will include all internal edges,
and its hairs will include all external (dangling) edges of the graph.
pub fn full_graph(&self) -> InternalSubGraph
pub fn full_graph(&self) -> InternalSubGraph
Returns an [InternalSubGraph] that includes all fully internal edges of the graph.
External (dangling) edges are excluded.
pub fn empty_subgraph<S>(&self) -> Swhere
S: SubSetLike,
pub fn empty_subgraph<S>(&self) -> Swhere
S: SubSetLike,
pub fn from_filter<S>(&self, filter: impl FnMut(&E) -> bool) -> Swhere
S: BaseSubgraph,
<S as SubSetLike>::Base: SubSetOps,
pub fn from_filter<S>(&self, filter: impl FnMut(&E) -> bool) -> Swhere
S: BaseSubgraph,
<S as SubSetLike>::Base: SubSetOps,
Creates a subgraph of type S by filtering edges based on their data.
Type Parameters
S: The type of subgraph to create, must implementBaseSubgraph.
Parameters
filter: A closure that takes edge data&Eand returnstrueif the edge should be included in the subgraph.
Returns
A new subgraph of type S.
pub fn nesting_node_from_subgraph(
&self,
internal_graph: InternalSubGraph,
) -> HedgeNode
pub fn nesting_node_from_subgraph( &self, internal_graph: InternalSubGraph, ) -> HedgeNode
Creates a [HedgeNode] from a given [InternalSubGraph].
The internal_graph of the new HedgeNode is the one provided.
The hairs of the HedgeNode are calculated as all half-edges incident to the
internal_graph that are not part of the internal_graph itself.
Parameters
internal_graph: TheInternalSubGraphto form the core of theHedgeNode.
Panics
Panics if the provided internal_graph is not valid for this graph (e.g.,
if it refers to hedges outside the graph’s bounds or is not truly internal).
pub fn remove_internal_hedges(&self, subgraph: &SubSet<Hedge>) -> SubSet<Hedge>
pub fn count_internal_edges<S>(&self, subgraph: &S) -> usizewhere
S: SubSetLike,
pub fn count_internal_edges<S>(&self, subgraph: &S) -> usizewhere
S: SubSetLike,
Counts the number of full internal edges within the given subgraph.
An edge is considered internal if both its half-edges are included in the subgraph.
This method avoids double-counting by only counting an edge once.
Parameters
subgraph: The subgraphSin which to count internal edges.
Returns
The number of full internal edges.
pub fn n_edges(&self) -> usize
pub fn n_externals(&self) -> usize
pub fn n_externals(&self) -> usize
Returns the number of external (dangling/identity) half-edges in the graph.
pub fn n_internals(&self) -> usize
pub fn n_internals(&self) -> usize
Returns the number of internal (paired) half-edges in the graph. Note that this counts half-edges, so a single full internal edge contributes 2 to this count.
pub fn number_of_nodes_in_subgraph<S>(&self, subgraph: &S) -> usizewhere
S: SubSetLike,
pub fn number_of_nodes_in_subgraph<S>(&self, subgraph: &S) -> usizewhere
S: SubSetLike,
pub fn node_degrees_in_subgraph(
&self,
subgraph: &InternalSubGraph,
) -> AHashMap<NodeIndex, usize>
pub fn node_degrees_in_subgraph( &self, subgraph: &InternalSubGraph, ) -> AHashMap<NodeIndex, usize>
Calculates the degree of each node within the context of a given InternalSubGraph.
The degree of a node in this context is the number of half-edges from the subgraph
that are incident to that node.
Parameters
subgraph: TheInternalSubGraphto calculate node degrees from.
Returns
An AHashMap mapping each NodeIndex (for nodes involved in the subgraph)
to its degree within that subgraph.
pub fn owned_neighbors<S>(&self, subgraph: &S, pos: Hedge) -> SubSet<Hedge>where
S: SubGraphLike,
pub fn owned_neighbors<S>(&self, subgraph: &S, pos: Hedge) -> SubSet<Hedge>where
S: SubGraphLike,
including pos
pub fn connected_neighbors<S>(
&self,
subgraph: &S,
pos: Hedge,
) -> Option<SubSet<Hedge>>where
S: SubGraphLike,
pub fn get_edge_data(&self, edge: Hedge) -> &E
pub fn hedge_pair(&self, hedge: Hedge) -> HedgePair
pub fn get_edge_data_full(&self, hedge: Hedge) -> EdgeData<&E>
pub fn flow(&self, hedge: Hedge) -> Flow
pub fn flow(&self, hedge: Hedge) -> Flow
Gives the underlying orientation of this half-edge.
pub fn superficial_hedge_orientation(&self, hedge: Hedge) -> Option<Flow>
pub fn underlying_hedge_orientation(&self, hedge: Hedge) -> Flow
pub fn neighbors(&self, hedge: Hedge) -> <N as NodeStorage>::NeighborsIter<'_>
pub fn iter_crown(&self, id: NodeIndex) -> <N as NodeStorage>::NeighborsIter<'_>
pub fn iter_crown_in<'a, S>(
&'a self,
subgraph: &'a S,
id: NodeIndex,
) -> impl Iterator<Item = Hedge> + 'awhere
S: SubSetLike,
pub fn id_from_crown<'a>( &'a self, neighbors: <N as NodeStorage>::NeighborsIter<'a>, ) -> Option<NodeIndex>
pub fn involved_node_crown( &self, hedge: Hedge, ) -> Option<<N as NodeStorage>::NeighborsIter<'_>>
pub fn involved_node_id(&self, hedge: Hedge) -> Option<NodeIndex>
pub fn node_id(&self, hedge: Hedge) -> NodeIndex
pub fn is_self_loop(&self, hedge: Hedge) -> bool
pub fn is_dangling(&self, hedge: Hedge) -> bool
pub fn nodes<S>(&self, subgraph: &S) -> Vec<NodeIndex>where
S: SubSetLike,
pub fn nodes<S>(&self, subgraph: &S) -> Vec<NodeIndex>where
S: SubSetLike,
Collect all nodes in the subgraph (all nodes that the hedges are connected to)
pub fn edges<S>(&self, subgraph: &S) -> Vec<EdgeIndex>where
S: SubSetLike,
pub fn edges<S>(&self, subgraph: &S) -> Vec<EdgeIndex>where
S: SubSetLike,
Collect all edges in the subgraph
(This is without double counting, i.e. if two half-edges are part of the same edge, only one EdgeIndex will be collected)
pub fn paired_edges<S>(&self, subgraph: &S) -> Vec<EdgeIndex>where
S: SubSetLike,
pub fn paired_edges<S>(&self, subgraph: &S) -> Vec<EdgeIndex>where
S: SubSetLike,
Collect all edges in the subgraph
(This is without double counting, i.e. if two half-edges are part of the same edge, only one EdgeIndex will be collected)
pub fn map_data_ref<'a, E2, V2, H2>( &'a self, node_map: impl FnMut(&'a HedgeGraph<E, V, H, N>, <N as NodeStorage>::NeighborsIter<'a>, &'a V) -> V2, edge_map: impl FnMut(&'a HedgeGraph<E, V, H, N>, EdgeIndex, HedgePair, EdgeData<&'a E>) -> EdgeData<E2>, hedge_map: impl FnMut(Hedge, &'a H) -> H2, ) -> HedgeGraph<E2, V2, H2, <N as NodeStorageOps>::OpStorage<V2>>
pub fn to_ref( &self, ) -> HedgeGraph<&E, &V, &H, <N as NodeStorageOps>::OpStorage<&V>>
pub fn map_data_ref_result<'a, E2, V2, H2, Er>( &'a self, node_map: impl FnMut(&'a HedgeGraph<E, V, H, N>, <N as NodeStorage>::NeighborsIter<'a>, &'a V) -> Result<V2, Er>, edge_map: impl FnMut(&'a HedgeGraph<E, V, H, N>, EdgeIndex, HedgePair, EdgeData<&'a E>) -> Result<EdgeData<E2>, Er>, hedge_map: impl FnMut((Hedge, &'a H)) -> Result<H2, Er>, ) -> Result<HedgeGraph<E2, V2, H2, <N as NodeStorageOps>::OpStorage<V2>>, Er>
pub fn just_structure( &self, ) -> HedgeGraph<(), (), (), <N as NodeStorageOps>::OpStorage<()>>
pub fn map_nodes_ref<'a, V2>( &'a self, f: impl FnMut(&'a HedgeGraph<E, V, H, N>, <N as NodeStorage>::NeighborsIter<'a>, &'a V) -> V2, ) -> HedgeGraph<&'a E, V2, &'a H, <N as NodeStorageOps>::OpStorage<V2>>
pub fn new_smart_hedgevec<T>( &self, f: &impl Fn(HedgePair, EdgeData<&E>) -> EdgeData<T>, ) -> SmartEdgeVec<T>
pub fn new_edgevec<T>( &self, f: impl FnMut(&E, EdgeIndex, &HedgePair) -> T, ) -> EdgeVec<T>
pub fn new_nodevec<'a, T>( &'a self, f: impl FnMut(NodeIndex, <N as NodeStorage>::NeighborsIter<'a>, &'a V) -> T, ) -> NodeVec<T>
pub fn new_hedgevec<T>(&self, f: impl FnMut(Hedge, &H) -> T) -> HedgeVec<T>
pub fn new_edgevec_from_iter<T, I>(
&self,
iter: I,
) -> Result<EdgeVec<T>, HedgeGraphError>where
I: IntoIterator<Item = T>,
pub fn non_cut_edges(&self) -> AHashSet<SubSet<Hedge>>
pub fn non_cut_edges(&self) -> AHashSet<SubSet<Hedge>>
all sets of full edges that do not disconnect the graph/ increase its connected components
pub fn non_bridges(&self) -> SubSet<Hedge>
pub fn non_bridges_of<S>(&self, subgraph: &S) -> SubSet<Hedge>where
S: SubSetLike<Base = SubSet<Hedge>> + SubGraphLike,
pub fn bridges_of<S>(&self, subgraph: &S) -> SubSet<Hedge>where
S: SubSetLike<Base = SubSet<Hedge>> + SubGraphLike,
pub fn bridges(&self) -> SubSet<Hedge>
pub fn combine_to_single_hedgenode(&self, source: &[NodeIndex]) -> HedgeNode
pub fn all_cuts_from_ids(
&self,
source: &[NodeIndex],
target: &[NodeIndex],
) -> Vec<(SubSet<Hedge>, OrientedCut, SubSet<Hedge>)>where
N: NodeStorageOps,
pub fn tadpoles(&self, externals: &[NodeIndex]) -> Vec<SubSet<Hedge>>
pub fn all_bonds<R>(&self, size: &R) -> Vec<SubSet<Hedge>>where
R: RangeBounds<usize>,
pub fn a_bond( &self, cond: &impl Fn(&SubSet<Hedge>) -> bool, ) -> Option<SubSet<Hedge>>
pub fn all_bonds_of<S, R>(&self, subgraph: &S, size: &R) -> Vec<SubSet<Hedge>>where
S: SubGraphLike<Base = SubSet<Hedge>>,
R: RangeBounds<usize>,
pub fn a_bond_of<S>(
&self,
subgraph: &S,
cond: &impl Fn(&SubSet<Hedge>) -> bool,
) -> Option<SubSet<Hedge>>where
S: SubGraphLike<Base = SubSet<Hedge>>,
pub fn all_cuts(
&self,
source: HedgeNode,
target: HedgeNode,
) -> Vec<(SubSet<Hedge>, OrientedCut, SubSet<Hedge>)>where
N: NodeStorageOps,
pub fn all_s_t_cuts_impl<S>(
&self,
subgraph: &S,
s_connectivity: usize,
s: HedgeNode,
t: &HedgeNode,
t_connectivity: usize,
regions: &mut AHashSet<HedgeNode>,
)where
S: SubSetLike<Base = SubSet<Hedge>>,
pub fn all_spanning_forests_of<S>(
&self,
subgraph: &S,
) -> Vec<<S as SubSetLike>::Base>
pub fn all_spanning_forests_of<S>( &self, subgraph: &S, ) -> Vec<<S as SubSetLike>::Base>
Gives all subgraphs corresponding to all the spanning trees of the graph.
See Winter, Pawel, “An Algorithm for the Enumeration of Spanning Trees,” BIT Numerical Mathematics 26, no. 1 (1986): 44–62, https://doi.org/10.1007/BF01939361.
pub fn cyclotomatic_number<S>(&self, subgraph: &S) -> usizewhere
S: SubGraphLike,
pub fn cycle_basis(&self) -> (Vec<Cycle>, SubSet<Hedge>)
pub fn cycle_basis_of<S>(&self, subgraph: &S) -> (Vec<Cycle>, SubSet<Hedge>)where
S: SubSetLike<Base = SubSet<Hedge>> + SubGraphLike,
pub fn order_basis(&self, basis: &[HedgeNode]) -> Vec<Vec<InternalSubGraph>>
pub fn all_cycles(&self) -> Vec<Cycle>
pub fn all_cycle_sym_diffs( &self, ) -> Result<Vec<InternalSubGraph>, TryFromIntError>
pub fn all_cycle_unions(&self) -> AHashSet<InternalSubGraph>
pub fn paton_count_loops( &self, subgraph: &InternalSubGraph, start: &NodeIndex, ) -> Result<usize, HedgeGraphError>
pub fn all_spinneys_with_basis( &self, basis: &[&InternalSubGraph], ) -> AHashSet<HedgeNode>
pub fn all_spinneys_rec( &self, spinneys: &mut AHashSet<HedgeNode>, cycle_sums: Vec<HedgeNode>, )
pub fn all_spinneys( &self, ) -> AHashMap<InternalSubGraph, Vec<(InternalSubGraph, Option<InternalSubGraph>)>>
pub fn all_spinneys_alt(&self) -> AHashSet<InternalSubGraph>
pub fn count_connected_components<S>(&self, subgraph: &S) -> usizewhere
S: SubGraphLike,
pub fn connected_components<S>(&self, subgraph: &S) -> Vec<SubSet<Hedge>>where
S: SubGraphLike,
pub fn iter_hedges(&self) -> impl Iterator<Item = (Hedge, &H)>
pub fn iter_nodes(
&self,
) -> impl Iterator<Item = (NodeIndex, <N as NodeStorage>::NeighborsIter<'_>, &V)>
pub fn iter_nodes( &self, ) -> impl Iterator<Item = (NodeIndex, <N as NodeStorage>::NeighborsIter<'_>, &V)>
Iterate over all nodes, returns an iterator that yields
pub fn iter_node_ids(&self) -> impl Iterator<Item = NodeIndex>
pub fn iter_edge_ids_of<'a, S>(
&'a self,
subgraph: &'a S,
) -> EdgeIter<'a, E, V, H, S, N, <S as SubSetLike>::BaseIter<'a>>where
S: SubSetLike,
pub fn iter_edges_of<'a, S>(
&'a self,
subgraph: &'a S,
) -> impl Iterator<Item = (HedgePair, EdgeIndex, EdgeData<&'a E>)> + 'awhere
S: SubSetLike,
pub fn iter_edges( &self, ) -> impl Iterator<Item = (HedgePair, EdgeIndex, EdgeData<&E>)>
pub fn iter_nodes_of<'a, S>(
&'a self,
subgraph: &'a S,
) -> impl Iterator<Item = (NodeIndex, <N as NodeStorage>::NeighborsIter<'a>, &'a V)>where
S: SubSetLike,
<N as NodeStorage>::NeighborsIter<'a>: Clone,
pub fn dot_impl_fmt<S, Str1>( &self, writer: &mut impl Write, subgraph: &S, graph_info: Str1, hedge_attr: &impl Fn(&H) -> Option<String>, edge_attr: &impl Fn(&E) -> Option<String>, node_attr: &impl Fn(&V) -> Option<String>, ) -> Result<(), Error>
pub fn dot_impl_io<S, Str1>( &self, writer: &mut impl Write, subgraph: &S, graph_info: Str1, hedge_attr: &impl Fn(&H) -> Option<String>, edge_attr: &impl Fn(&E) -> Option<String>, node_attr: &impl Fn(&V) -> Option<String>, ) -> Result<(), Error>
pub fn dot_impl<S, Str1>( &self, subgraph: &S, graph_info: Str1, hedge_attr: &impl Fn(&H) -> Option<String>, edge_attr: &impl Fn(&E) -> Option<String>, node_attr: &impl Fn(&V) -> Option<String>, ) -> String
pub fn dot<S>(&self, node_as_graph: &S) -> Stringwhere
S: SubGraphLike,
pub fn dot_display<S>(&self, node_as_graph: &S) -> String
pub fn dot_label<S>(&self, node_as_graph: &S) -> String
pub fn base_dot(&self) -> String
pub fn topo_sort_kahn_of<S>(
&self,
subgraph: &S,
) -> Result<Vec<NodeIndex>, TopoError>where
S: SubSetLike,
pub fn topo_sort_kahn(&self) -> Result<Vec<NodeIndex>, TopoError>
pub fn is_reachable(&self, source: NodeIndex, target: NodeIndex) -> bool
pub fn is_reachable(&self, source: NodeIndex, target: NodeIndex) -> bool
Checks if there is a path from source to target in the graph.
Uses breadth-first search to determine reachability. This method only follows source half-edges (outgoing edges) to traverse the directed graph structure.
Arguments
source- The source nodetarget- The target node
Returns
true if there is a directed path from source to target, false otherwise.
Half-Edge Traversal
The algorithm only follows half-edges with Flow::Source to ensure
it respects the directed nature of edges in the graph.
pub fn dot_serialize_of<S>(
&self,
subgraph: &S,
global: impl Into<GlobalData>,
hedge_map: &impl Fn(&H) -> DotHedgeData,
edge_map: &impl Fn(&E) -> DotEdgeData,
node_map: &impl Fn(&V) -> DotVertexData,
) -> Stringwhere
S: SubGraphLike,
pub fn dot_serialize_io( &self, writer: &mut impl Write, global: impl Into<GlobalData>, hedge_map: &impl Fn(&H) -> DotHedgeData, edge_map: &impl Fn(&E) -> DotEdgeData, node_map: &impl Fn(&V) -> DotVertexData, ) -> Result<(), Error>
pub fn dot_serialize_fmt( &self, writer: &mut impl Write, global: impl Into<GlobalData>, hedge_map: &impl Fn(&H) -> DotHedgeData, edge_map: &impl Fn(&E) -> DotEdgeData, node_map: &impl Fn(&V) -> DotVertexData, ) -> Result<(), Error>