pub struct GammaloopSymbols {Show 78 fields
pub integrand: Symbol,
pub tree_denom_wrapper: Symbol,
pub killing_func: Symbol,
pub is_function: Symbol,
pub is_symbol: Symbol,
pub ufozero: Symbol,
pub _linear: Symbol,
pub linearize: Symbol,
pub loop_mom: Symbol,
pub edgeid: Symbol,
pub uvaind: Symbol,
pub edgeaind: Symbol,
pub dummyaind: Symbol,
pub hedgeaind: Symbol,
pub vertexaind: Symbol,
pub vertexid: Symbol,
pub source_id: Symbol,
pub sink_id: Symbol,
pub orientation_delta: Symbol,
pub ubar: Symbol,
pub hfunction_lu_cut: Symbol,
pub hfunction_left_th: Symbol,
pub hfunction_right_th: Symbol,
pub eta: Symbol,
pub eta_left: Symbol,
pub eta_right: Symbol,
pub deta_lu_cut: Symbol,
pub deta_left_th: Symbol,
pub deta_right_th: Symbol,
pub vbar: Symbol,
pub ose: Symbol,
pub energy: Symbol,
pub v: Symbol,
pub u: Symbol,
pub color_wrap: Symbol,
pub dim_epsilon: Symbol,
pub epsilon: Symbol,
pub epsilonbar: Symbol,
pub rescale: Symbol,
pub integrated_loop_scale: Symbol,
pub rescale_mass: Symbol,
pub rescale_star: Symbol,
pub pi: Symbol,
pub m_uv_expansion: Symbol,
pub m_uv_vacuum: Symbol,
pub renormalization_localization_scale: Symbol,
pub mu_r_sq: Symbol,
pub sign: Symbol,
pub theta: Symbol,
pub broadcasting_sqrt: Symbol,
pub selected: Symbol,
pub expansion: Symbol,
pub delta_vec: Symbol,
pub emr_mom: Symbol,
pub emr_vec: Symbol,
pub dot: Symbol,
pub external_mom: Symbol,
pub dim: Symbol,
pub coeff: Symbol,
pub localizing_integrand: Symbol,
pub uv_subgraph: Symbol,
pub uv_approx: Symbol,
pub uv_integrate: Symbol,
pub uv_series: Symbol,
pub uv_truncate: Symbol,
pub ct_marker: Symbol,
pub nc2_1: Symbol,
pub expr: Symbol,
pub num: Symbol,
pub den: Symbol,
pub radius_left: Symbol,
pub radius_star_left: Symbol,
pub uv_damp_plus_left: Symbol,
pub uv_damp_minus_left: Symbol,
pub radius_right: Symbol,
pub radius_star_right: Symbol,
pub uv_damp_plus_right: Symbol,
pub uv_damp_minus_right: Symbol,
}Fields
integrand: Symboltree_denom_wrapper: Symbolwrapper function for the 4d bridge denominators
killing_func: Symbolis_function: Symbolis_symbol: Symbolufozero: Symbol_linear: Symbollinearize: Symbolloop_mom: Symboledgeid: Symboluvaind: Symboledgeaind: Symboldummyaind: Symbolhedgeaind: Symbolvertexaind: Symbolvertexid: Symbolsource_id: Symbolsink_id: Symbolorientation_delta: Symbolubar: Symbolhfunction_lu_cut: Symbolhfunction_left_th: Symbolhfunction_right_th: Symboleta: Symboleta_left: Symboleta_right: Symboldeta_lu_cut: Symboldeta_left_th: Symboldeta_right_th: Symbolvbar: Symbolose: Symbolenergy: Symbolv: Symbolu: Symbolcolor_wrap: Symboldim_epsilon: SymbolEpsilon for dimensional regularization
epsilon: Symbolepsilonbar: Symbolrescale: Symbolintegrated_loop_scale: SymbolBookkeeping scale for integrated vacuum masses and consumed loop measures.
rescale_mass: Symbolrescale_star: Symbolpi: Symbolm_uv_expansion: SymbolUV mass used only as the auxiliary expansion/deformation scale in local UV series.
This symbol prints as mUVexp. Public runtime output should not depend on this
name after the endpoint mass-role collapse.
m_uv_vacuum: SymbolUV vacuum mass used by integrated counterterms and the vacuum-integral basis.
This symbol prints as mUV and is the public symbolic representative of the
general.m_uv runtime setting.
renormalization_localization_scale: SymbolUV localization scale factor
mu_r_sq: Symbolsign: Symboltheta: Symbolbroadcasting_sqrt: Symbolselected: Symbolfor selecting orientations at generation
expansion: SymbolFor analytic UV profiling
delta_vec: SymbolFor selecting a concete index.
emr_mom: SymbolQ(<edgeid>, index___)
emr_vec: Symboldot: Symbolexternal_mom: Symboldim: Symbolcoeff: Symbollocalizing_integrand: Symboluv_subgraph: Symboluv_approx: Symboluv_integrate: Symboluv_series: Symboluv_truncate: Symbolct_marker: SymbolMarker for the ct term in the UV integrand
nc2_1: Symbolexpr: Symbolnum: Symbolden: SymbolDenominator wrapper, den(<edge_id>, <momentum>, <mass>, <full_expr>)
(no power and should not be multiplied in but divided!).
radius_left: Symbolradius_star_left: Symboluv_damp_plus_left: Symboluv_damp_minus_left: Symbolradius_right: Symbolradius_star_right: Symboluv_damp_plus_right: Symboluv_damp_minus_right: SymbolImplementations
Sourceimpl GammaloopSymbols
impl GammaloopSymbols
pub fn integrand<O: GraphOrientation>(&self, i: usize, orientation: &O) -> Atom
pub fn wrap_tree_denoms<'a>(&self, arg: impl Into<AtomOrView<'a>>) -> Atom
pub fn do_dot_product_in_sqrt<'a>(&self, arg: impl Into<AtomOrView<'a>>) -> Atom
pub fn to_broadcasting_sqrt<'a>(&self, arg: impl Into<AtomOrView<'a>>) -> Atom
Sourcepub fn split_mom_pattern_simple(&self, e: EdgeIndex) -> Replacement
pub fn split_mom_pattern_simple(&self, e: EdgeIndex) -> Replacement
Add the sign by splitting Q(i,mu)-> Q3(i,mu)+OSE(i)*σ(i)*δ(cind(0),mu)