macro_rules! debug_cache_search {
($integrand:expr, $msg:expr) => { ... };
}Expand description
Helper macro for missed cache hit detection in debug mode
macro_rules! debug_cache_search {
($integrand:expr, $msg:expr) => { ... };
}Helper macro for missed cache hit detection in debug mode