pub struct StringSerializedAtom(pub Atom);Tuple Fields
0: AtomMethods from Deref<Target = Atom>
pub const I_STR: &'static str = "𝑖"
pub fn is_zero(&self) -> bool
pub fn is_one(&self) -> bool
pub fn to_plain_string(&self) -> String
pub fn to_plain_string(&self) -> String
Print the atom using the portable [PrintOptions::file()] options.
pub fn with_stats<F>(&self, op: F, o: &StatsOptions) -> Atomwhere
F: Fn(AtomView<'_>) -> Atom,
pub fn with_stats<F>(&self, op: F, o: &StatsOptions) -> Atomwhere
F: Fn(AtomView<'_>) -> Atom,
Print statistics about the operation op, such as its duration and term growth.
pub fn repeat_map<F>(&mut self, op: F)where
F: Fn(AtomView<'_>) -> Atom,
pub fn repeat_map<F>(&mut self, op: F)where
F: Fn(AtomView<'_>) -> Atom,
Repeatedly apply an operation on the atom until the atom no longer changes.
pub fn to_num<T>(&mut self, coeff: T) -> &mut Numwhere
T: Into<Coefficient>,
pub fn to_var(&mut self, id: Symbol) -> &mut Var
pub fn to_fun(&mut self, id: Symbol) -> &mut Fun
pub fn to_pow(&mut self, base: AtomView<'_>, exp: AtomView<'_>) -> &mut Pow
pub fn to_mul(&mut self) -> &mut Mul
pub fn to_add(&mut self) -> &mut Add
pub fn set_from_view(&mut self, view: &AtomView<'_>)
pub fn as_view(&self) -> AtomView<'_>