pub struct Integrate {Show 23 fields
pub process: Vec<ProcessRef>,
pub integrand_name: Vec<String>,
pub n_cores: Option<usize>,
pub workspace_path: Option<PathBuf>,
pub target: Vec<String>,
pub restart: bool,
pub uncorrelated: bool,
pub show_max_weight_info: bool,
pub no_show_integration_statistics: bool,
pub show_phase: ShowPhaseOption,
pub show_top_discrete_grid: bool,
pub show_discrete_contributions_sum: bool,
pub sort_contributions: ContributionSortOption,
pub show_max_weight_info_for_discrete_bins: bool,
pub show_summary_only: bool,
pub no_stream_iterations: bool,
pub no_stream_updates: bool,
pub renderer: RendererOption,
pub batch_size: Option<usize>,
pub batch_timing: f64,
pub min_time_between_status_updates: f64,
pub max_table_width: usize,
pub write_results_for_each_iteration: bool,
}Fields
process: Vec<ProcessRef>Process reference: #<id>, name:<name>, or <id>/<name>; repeat with -i to select multiple integrands
integrand_name: Vec<String>The integrand name to integrate; repeat with -p to select multiple integrands
n_cores: Option<usize>Number of cores to parallelize over
workspace_path: Option<PathBuf>Workspace directory used for resumable integration state and persisted results
target: Vec<String>Specify a target as either re im / re,im for one shared target or process@integrand=re,im
restart: boolWhether to restart the integration from scratch, or continue from a previous run if possible
Use one independent sampling/training grid per selected integrand instead of a shared grid
show_max_weight_info: boolShow the overall max-weight details table
no_show_integration_statistics: boolHide integration statistics during intermediate iteration updates
show_phase: ShowPhaseOptionControl which complex phase is shown in integration summary tables
show_top_discrete_grid: boolShow monitoring rows for the first non-trivial discrete dimension
show_discrete_contributions_sum: boolShow the summed discrete contributions block independently of per-bin rows
sort_contributions: ContributionSortOptionSort discrete contribution rows by index, absolute integral, or error
show_max_weight_info_for_discrete_bins: boolShow per-bin max-weight information for the first non-trivial discrete dimension
show_summary_only: boolOnly render the saved integration summary, without performing integration work
no_stream_iterations: boolDisable streaming of end-of-iteration integration summaries in interactive terminals
no_stream_updates: boolDisable live streaming of in-iteration integration status updates
renderer: RendererOptionRenderer used for interactive streaming integration updates
batch_size: Option<usize>Evaluate each iteration in per-core batches of this size
batch_timing: f64Target per-core batch wall time in seconds when batch size is not specified
min_time_between_status_updates: f64Minimum time between streamed in-iteration status updates
max_table_width: usizeMaximum width used when normalizing integration status tables
write_results_for_each_iteration: boolKeep per-iteration result and observable snapshot files in addition to the latest snapshots
Implementations
Sourceimpl Integrate
impl Integrate
pub fn from_slots<I, S>(slots: I) -> Self
pub fn with_single_target(self, target: Complex<F<f64>>) -> Self
pub fn with_keyed_targets<I, S>(self, targets: I) -> Self
pub fn run( &self, state: &mut State, global_cli_settings: &CLISettings, ) -> Result<IntegrationOutput>