pub struct LeftThresholdId(pub usize);Tuple Fields
0: usizeTrait Implementations
Sourceimpl Add for LeftThresholdId
impl Add for LeftThresholdId
Sourcetype Output = LeftThresholdId
type Output = LeftThresholdId
The resulting type after applying the
+ operator.Sourceimpl AddAssign for LeftThresholdId
impl AddAssign for LeftThresholdId
Sourcefn add_assign(&mut self, other: LeftThresholdId)
fn add_assign(&mut self, other: LeftThresholdId)
Performs the
+= operation. Read moreSourceimpl<'__de, __Context> BorrowDecode<'__de, __Context> for LeftThresholdId
impl<'__de, __Context> BorrowDecode<'__de, __Context> for LeftThresholdId
Sourcefn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>(
decoder: &mut __D,
) -> Result<Self, DecodeError>
fn borrow_decode<__D: BorrowDecoder<'__de, Context = __Context>>( decoder: &mut __D, ) -> Result<Self, DecodeError>
Attempt to decode this type with the given BorrowDecode.
Sourceimpl Clone for LeftThresholdId
impl Clone for LeftThresholdId
Sourcefn clone(&self) -> LeftThresholdId
fn clone(&self) -> LeftThresholdId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for LeftThresholdId
Sourceimpl Debug for LeftThresholdId
impl Debug for LeftThresholdId
Sourceimpl<__Context> Decode<__Context> for LeftThresholdId
impl<__Context> Decode<__Context> for LeftThresholdId
Sourceimpl<'de> Deserialize<'de> for LeftThresholdId
impl<'de> Deserialize<'de> for LeftThresholdId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Encode for LeftThresholdId
impl Encode for LeftThresholdId
impl Eq for LeftThresholdId
Sourceimpl From<LeftThresholdId> for usize
impl From<LeftThresholdId> for usize
Sourcefn from(value: LeftThresholdId) -> Self
fn from(value: LeftThresholdId) -> Self
Converts to this type from the input type.
Sourceimpl From<usize> for LeftThresholdId
impl From<usize> for LeftThresholdId
Sourceimpl Hash for LeftThresholdId
impl Hash for LeftThresholdId
Sourceimpl Ord for LeftThresholdId
impl Ord for LeftThresholdId
Sourcefn cmp(&self, other: &LeftThresholdId) -> Ordering
fn cmp(&self, other: &LeftThresholdId) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for LeftThresholdId
impl PartialEq for LeftThresholdId
Sourcefn eq(&self, other: &LeftThresholdId) -> bool
fn eq(&self, other: &LeftThresholdId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for LeftThresholdId
impl PartialOrd for LeftThresholdId
Sourceimpl Serialize for LeftThresholdId
impl Serialize for LeftThresholdId
impl StructuralPartialEq for LeftThresholdId
Sourceimpl Sub for LeftThresholdId
impl Sub for LeftThresholdId
Sourcetype Output = LeftThresholdId
type Output = LeftThresholdId
The resulting type after applying the
- operator.Sourceimpl SubAssign for LeftThresholdId
impl SubAssign for LeftThresholdId
Sourcefn sub_assign(&mut self, other: LeftThresholdId)
fn sub_assign(&mut self, other: LeftThresholdId)
Performs the
-= operation. Read moreAuto Trait Implementations
impl Freeze for LeftThresholdId
impl RefUnwindSafe for LeftThresholdId
impl Send for LeftThresholdId
impl Sync for LeftThresholdId
impl Unpin for LeftThresholdId
impl UnsafeUnpin for LeftThresholdId
impl UnwindSafe for LeftThresholdId